@@ -1,4 +1,9 @@
-use crate::{CursorImpl, Error, Preallocated, Prepared, execute::execute_with_parameters, handles::{self, State, Statement, StatementImpl}, parameter_collection::ParameterCollection};
+use crate::{
+    execute::execute_with_parameters,
+    handles::{self, State, Statement, StatementImpl},
+    parameter_collection::ParameterCollection,
+    CursorImpl, Error, Preallocated, Prepared,
+};
 use std::{borrow::Cow, thread::panicking};
 use widestring::{U16Str, U16String};
 
@@ -186,6 +191,12 @@ impl<'c> Connection<'c> {
         self.connection.rollback()
     }
 
+    /// Indicates the state of the connection. If `true` the connection has been lost. If `false`,
+    /// the connection is still active.
+    pub fn is_dead(&self) -> Result<bool, Error> {
+        self.connection.is_dead()
+    }
+
     /// Allows sending this connection to different threads. This Connection will still be only be
     /// used by one thread at a time, but it may be a different thread each time.
     ///
@@ -240,6 +251,54 @@ impl<'c> Connection<'c> {
     pub unsafe fn promote_to_send(self) -> force_send_sync::Send<Self> {
         force_send_sync::Send::new(self)
     }
+
+    /// Fetch the name of the database management system used by the connection and store it into
+    /// the provided `buf`.
+    pub fn fetch_database_management_system_name(&self, buf: &mut Vec<u16>) -> Result<(), Error> {
+        self.connection.fetch_database_management_system_name(buf)
+    }
+
+    /// Get the name of the database management system used by the connection.
+    pub fn database_management_system_name(&self) -> Result<String, Error> {
+        let mut buf = Vec::new();
+        self.fetch_database_management_system_name(&mut buf)?;
+        let name = U16String::from_vec(buf);
+        Ok(name.to_string().unwrap())
+    }
+
+    /// Maximum length of catalog names in bytes.
+    pub fn max_catalog_name_len(&self) -> Result<usize, Error> {
+        self.connection.max_catalog_name_len().map(|v| v as usize)
+    }
+
+    /// Maximum length of schema names in bytes.
+    pub fn max_schema_name_len(&self) -> Result<usize, Error> {
+        self.connection.max_schema_name_len().map(|v| v as usize)
+    }
+
+    /// Maximum length of table names in bytes.
+    pub fn max_table_name_len(&self) -> Result<usize, Error> {
+        self.connection.max_table_name_len().map(|v| v as usize)
+    }
+
+    /// Maximum length of column names in bytes.
+    pub fn max_column_name_len(&self) -> Result<usize, Error> {
+        self.connection.max_column_name_len().map(|v| v as usize)
+    }
+
+    /// Fetch the name of the current catalog being used by the connection and store it into the
+    /// provided `buf`.
+    pub fn fetch_current_catalog(&self, buf: &mut Vec<u16>) -> Result<(), Error> {
+        self.connection.fetch_current_catalog(buf)
+    }
+
+    /// Get the name of the current catalog being used by the connection.
+    pub fn current_catalog(&self) -> Result<String, Error> {
+        let mut buf = Vec::new();
+        self.fetch_current_catalog(&mut buf)?;
+        let name = U16String::from_vec(buf);
+        Ok(name.to_string().unwrap())
+    }
 }
 
 /// You can use this method to escape a password so it is suitable to be appended to an ODBC
