@@ -1,4 +1,7 @@
-use super::{Connection, Error, State, as_handle::AsHandle, drop_handle, error::IntoResult, logging::log_diagnostics};
+use super::{
+    as_handle::AsHandle, drop_handle, error::IntoResult, logging::log_diagnostics, Connection,
+    Error, State,
+};
 use log::debug;
 use odbc_sys::{
     AttrOdbcVersion, EnvironmentAttribute, FetchOrientation, HDbc, HEnv, Handle, HandleType,
@@ -44,6 +47,57 @@ impl Drop for Environment {
 }
 
 impl Environment {
+    /// Enable or disable (default) connection pooling for ODBC connections. Call this function
+    /// before creating the ODBC environment for which you want to enable connection pooling.
+    ///
+    /// See:
+    /// <https://docs.microsoft.com/en-us/sql/odbc/reference/develop-app/driver-manager-connection-pooling>
+    ///
+    /// # Safety
+    ///
+    /// > An ODBC driver must be fully thread-safe, and connections must not have thread affinity to
+    /// > support connection pooling. This means the driver is able to handle a call on any thread
+    /// > at any time and is able to connect on one thread, to use the connection on another thread,
+    /// > and to disconnect on a third thread.
+    pub unsafe fn set_connection_pooling(
+        scheme: odbc_sys::AttrConnectionPooling,
+    ) -> Result<(), Error> {
+        match SQLSetEnvAttr(
+            null_mut(),
+            odbc_sys::EnvironmentAttribute::ConnectionPooling,
+            scheme.into(),
+            0,
+        ) {
+            SqlReturn::ERROR => return Err(Error::NoDiagnostics),
+            SqlReturn::SUCCESS | SqlReturn::SUCCESS_WITH_INFO => Ok(()),
+            other => panic!(
+                "Unexpected Return value ('{:?}') for SQLSetEnvAttr then trying to set connection \
+                pooling to {:?}", other, scheme
+            ),
+        }
+    }
+
+    pub fn set_connection_pooling_matching(
+        &mut self,
+        matching: odbc_sys::AttrCpMatch,
+    ) -> Result<(), Error> {
+        unsafe {
+            match SQLSetEnvAttr(
+                self.handle,
+                odbc_sys::EnvironmentAttribute::CpMatch,
+                matching.into(),
+                0,
+            ) {
+                SqlReturn::ERROR => return Err(Error::NoDiagnostics),
+                SqlReturn::SUCCESS | SqlReturn::SUCCESS_WITH_INFO => Ok(()),
+                other => panic!(
+                    "Unexpected Return value ('{:?}') for SQLSetEnvAttr then trying to set \
+                    connection pooling maching to {:?}", other, matching
+                ),
+            }
+        }
+    }
+
     /// An allocated ODBC Environment handle
     ///
     /// # Safety
